==> redquicklib-1.6.0.tgz: package/lib/locationservice.js <==
import * as UIA from './actions/uiActions';
import GEO from './geocodeservice';
import * as Globals from './globals';
import * as GLOBALS from './global';
import {
    Platform,
    PermissionsAndroid
} from 'react-native';
import * as Titles from '../titles';
import ApiService from './apiservice';
import GeoCodeService from './geocodeservice';
import * as Util from './util';
import * as Common from './common';
export const CURRENT_ADDRESS = 'CURRENT_ADDRESS';
export const CURRENT_ADDRESS_NAME = 'CURRENT_ADDRESS_NAME';
export const CURRENT_LOCATION = 'CURRENT_LOCATION';
var lastlocation = null;
var promise = Promise.resolve();
var catcher = e => {
    if (e && e.message && e.message.json) {
        return e.message.json().then(c => UIA.log(c));
    }
    UIA.log(e);
};
var setkey = false;
var stopped = true;
var $geolocationid = null;
var geolocationid = null;
export default {
    stop: () => {
        if (geolocationid) {
            navigator.geolocation.clearWatch(geolocationid);
        }
        if ($geolocationid) {
            navigator.geolocation.clearWatch($geolocationid);
        }
        stopped = true;
    },
    start: (dispatch, getState, islaborer) => {
        var crd;
        if (!stopped) {
            return true;
        }
        stopped = false;
        var nextLocationUpdateTime = Date.now() - GLOBALS.LOCATION_UPDATE_THROTTLE;
        function success(pos) {
            crd = pos.coords ? pos.coords : pos;
            var distance = Util.getDistance(crd, lastlocation);
            if (lastlocation && distance < 40) {
                return;
            }
            lastlocation = crd;
            dispatch(UIA.UI(CURRENT_LOCATION, Object.assign({
                latitudeDelta: .013,
                longitudeDelta: 0.013
            }, crd)));
            if (Date.now() > nextLocationUpdateTime) {
                nextLocationUpdateTime = Date.now() + GLOBALS.LOCATION_UPDATE_THROTTLE;
            }
            else {
                return nextLocationUpdateTime;
            }

            promise = promise.then(() => {
                if (crd)
                    return Globals.setLocation(crd);
            });
            promise = promise.then(() => {
                if (!setkey) {
                    setkey = true;
                    return ApiService.getApiKey().then((apiKey) => {
                        GeoCodeService.setKey(apiKey);
                    });
                }
            }).then(() => {
                // return GEO.getGeoCodes(crd.latitude, crd.longitude).then(location => {
                //     var state = getState();
                //     var startaddress = Common.getAddress({
                //         props: {
                //             state
                //         }
                //     }, location, null, null, null);

                //     var address_name = Common.getAddressName(location);
                //     if (startaddress) {
                //         dispatch(UIA.UI(CURRENT_ADDRESS, startaddress));
                //         dispatch(UIA.UI(CURRENT_ADDRESS_NAME, address_name))
                //     }
                // });
            });
        }

        function error(err) {
            console.log('ERROR(' + err.code + '): ' + err.message);
        }

        options = {
            enableHighAccuracy: true,
            timeout: GLOBALS.LOCATION_UPDATE_THROTTLE,
            distanceFilter: 1,
            maximumAge: GLOBALS.LOCATION_UPDATE_THROTTLE
        };
        if (Platform.OS === 'android') {
            geolocationid = navigator.geolocation.watchPosition(success, error, options);
        }
        else {
            geolocationid = navigator.geolocation.watchPosition(success, error, options);
        }
    }
}

==> redquicklib-1.289.0.tgz: package/lib/locationservice.js <==
import * as UIA from './actions/uiActions';
import GEO from './geocodeservice';
import * as Globals from './globals';
import * as GLOBALS from './global';
import {
    Platform,
    PermissionsAndroid
} from 'react-native';
import * as Titles from './titles';
import ApiService from './apiservice';
import GeoCodeService from './geocodeservice';
import * as Util from './util';
import * as Common from './common';
export const CURRENT_ADDRESS = 'CURRENT_ADDRESS';
export const CURRENT_ADDRESS_NAME = 'CURRENT_ADDRESS_NAME';
export const CURRENT_LOCATION = 'CURRENT_LOCATION';
var lastlocation = null;
var promise = Promise.resolve();
var catcher = e => {
    if (e && e.message && e.message.json) {
        return e.message.json().then(c => UIA.log(c));
    }
    UIA.log(e);
};
var setkey = false;
var stopped = true;
var $geolocationid = null;
var geolocationid = null;
export default {
    stop: () => {
        if (geolocationid) {
            navigator.geolocation.clearWatch(geolocationid);
        }
        if ($geolocationid) {
            navigator.geolocation.clearWatch($geolocationid);
        }
        stopped = true;
    },
    start: (dispatch, getState, islaborer) => {
        var crd;
        if (!stopped) {
            return true;
        }
        stopped = false;
        var nextLocationUpdateTime = Date.now() - GLOBALS.LOCATION_UPDATE_THROTTLE;
        function success(pos) {
            crd = pos.coords ? pos.coords : pos;
            var distance = Util.getDistance(crd, lastlocation);
            if (lastlocation && distance < 40) {
                return;
            }
            lastlocation = crd;
            dispatch(UIA.UI(CURRENT_LOCATION, Object.assign({
                latitudeDelta: .013,
                longitudeDelta: 0.013
            }, crd)));
            if (Date.now() > nextLocationUpdateTime) {
                nextLocationUpdateTime = Date.now() + GLOBALS.LOCATION_UPDATE_THROTTLE;
            }
            else {
                return nextLocationUpdateTime;
            }

            promise = promise.then(() => {
                if (crd)
                    return Globals.setLocation(crd);
            });
            promise = promise.then(() => {
                if (!setkey) {
                    setkey = true;
                    return ApiService.getApiKey().then((apiKey) => {
                        GeoCodeService.setKey(apiKey);
                    });
                }
            }).then(() => {
                // return GEO.getGeoCodes(crd.latitude, crd.longitude).then(location => {
                //     var state = getState();
                //     var startaddress = Common.getAddress({
                //         props: {
                //             state
                //         }
                //     }, location, null, null, null);

                //     var address_name = Common.getAddressName(location);
                //     if (startaddress) {
                //         dispatch(UIA.UI(CURRENT_ADDRESS, startaddress));
                //         dispatch(UIA.UI(CURRENT_ADDRESS_NAME, address_name))
                //     }
                // });
            });
        }

        function error(err) {
            console.log('ERROR(' + err.code + '): ' + err.message);
        }

        options = {
            enableHighAccuracy: true,
            timeout: GLOBALS.LOCATION_UPDATE_THROTTLE,
            distanceFilter: 1,
            maximumAge: GLOBALS.LOCATION_UPDATE_THROTTLE
        };
        if (Platform.OS === 'android') {
            geolocationid = navigator.geolocation.watchPosition(success, error, options);
        }
        else {
            geolocationid = navigator.geolocation.watchPosition(success, error, options);
        }
    }
}
